@@ -56,7 +56,9 @@ class SendGrid(object):
                 "create": "/api/newsletter/category/create.json",
                 "del": "/api/newsletter/category/remove.json",
                 "list": "/api/newsletter/category/list.json",
-                "add": "/api/newsletter/category/add.json"}
+                "add": "/api/newsletter/category/add.json"},
+            "stats":{
+                "get": "/apiv2/customer.stats.json"}
         }
 
     def build_params(self, d=None):
@@ -222,6 +224,10 @@ class SendGrid(object):
     def del_category(self, category, name):
         return self.call('category', 'del', dict(category=category, name=name))
 
+    def get_category_stats(self, category, user, **fields):
+        '''other fields can be days, start_date, end_date'''
+        return self.call('stats', 'get', dict(category=category, user=user, **fields))
+
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
                         newsletter_name,  # existing newsletter_name to be cloned
